@@ -9,7 +9,7 @@
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * $Id: mailbox_display.php,v 1.321 2003/03/27 16:47:38 philippe_mingo Exp $
+ * $Id: mailbox_display.php,v 1.321.2.9 2003/06/29 20:14:58 stekkel Exp $
  */
 
 require_once(SM_PATH . 'functions/strings.php');
@@ -73,11 +73,13 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     if (handleAsSent($mailbox)) {
        $msg['FROM'] = $msg['TO'];
     }
+    $msg['FROM'] = parseAddress($msg['FROM'],1);
+    
        /*
         * This is done in case you're looking into Sent folders,
         * because you can have multiple receivers.
         */
-        
+
     $senderNames = $msg['FROM'];
     $senderName  = '';
     if (sizeof($senderNames)){
@@ -91,11 +93,11 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                 $senderName .= htmlspecialchars($senderNames_part[0]);
             }
         }
-    } 
-    
-    $subject_full = decodeHeader($msg['SUBJECT']);
-    $subject = processSubject($subject_full, $indent_array[$msg['ID']]);
-
+    }
+    $senderName = str_replace('&nbsp;',' ',$senderName);
+    $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
+    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
+    $subject = str_replace('&nbsp;',' ',$subject);    
     echo html_tag( 'tr','','','','VALIGN="top"') . "\n";
 
     if (isset($msg['FLAG_FLAGGED']) && ($msg['FLAG_FLAGGED'] == true)) {
@@ -132,34 +134,40 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     } else {
         $searchstr = '';
     }
-    /**
-    * AAAAH! Make my eyes stop bleeding!
-    * Who wrote this?!
-    */
-    if (is_array($message_highlight_list) && count($message_highlight_list)){
+    
+    if (is_array($message_highlight_list) && count($message_highlight_list)) {
+        $msg['TO'] = parseAddress($msg['TO']);
+        $msg['CC'] = parseAddress($msg['CC']);
         foreach ($message_highlight_list as $message_highlight_list_part) {
             if (trim($message_highlight_list_part['value']) != '') {
                 $high_val   = strtolower($message_highlight_list_part['value']);
                 $match_type = strtoupper($message_highlight_list_part['match_type']);
-                if ($match_type == 'TO_CC') {
-                    foreach ($msg['TO'] as $address) {
-                        if (strstr('^^' . strtolower($address[0]), $high_val) ||
-                            strstr('^^' . strtolower($address[1]), $high_val)) {
-                            $hlt_color = $message_highlight_list_part['color'];
-                            continue;
-                        }
-                    }
-                    foreach ($msg['CC'] as $address) {
-                        if( strstr('^^' . strtolower($address[0]), $high_val) ||
-                            strstr('^^' . strtolower($address[1]), $high_val)) {
-                            $hlt_color = $message_highlight_list_part['color'];
-                            continue;
-                        }
-                    }
+                if($match_type == 'TO_CC') {
+                    $match = array('TO', 'CC');
                 } else {
-                    if (strstr('^^' . strtolower($msg[$match_type]), $high_val)) {
-                        $hlt_color = $message_highlight_list_part['color'];
-                        continue;
+                    $match = array($match_type);
+                }
+                foreach($match as $match_type) {
+                    switch($match_type) {
+                        case('TO'):
+                        case('CC'):
+                        case('FROM'):
+                            foreach ($msg[$match_type] as $address) {
+                                $address[0] = decodeHeader($address[0]);
+                                $address[1] = decodeHeader($address[1]);
+                                if (strstr('^^' . strtolower($address[0]), $high_val) ||
+                                    strstr('^^' . strtolower($address[1]), $high_val)) {
+                                    $hlt_color = $message_highlight_list_part['color'];
+                                    break 4;
+                                }
+                            }
+                            break;
+                        default:
+                            if (strstr('^^' . strtolower($msg[$match_type]), $high_val)) {
+                                $hlt_color = $message_highlight_list_part['color'];
+                                break 3; 
+                            }
+                            break;
                     }
                 }
             }
@@ -209,11 +217,11 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                 $td_str .= '<a href="read_body.php?mailbox='.$urlMailbox
                         .  '&amp;passed_id='. $msg["ID"]
                         .  '&amp;startMessage='.$start_msg.$searchstr.'"';
-                do_hook("subject_link");
-                if ($subject != $subject_full) {
+                $td_str .= ' ' .concat_hook_function('subject_link', array($start_msg, $searchstr));
+                if ($subject != $msg['SUBJECT']) {
                     $title = get_html_translation_table(HTML_SPECIALCHARS);
                     $title = array_flip($title);
-                    $title = strtr($subject_full, $title);
+                    $title = strtr($msg['SUBJECT'], $title);
                     $title = str_replace('"', "''", $title);
                     $td_str .= " title=\"$title\"";
                 }
@@ -223,60 +231,62 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
             case 5: /* flags */
                 $stuff = false;
                 $td_str = "<b><small>";
-		
+
                 if (isset($msg['FLAG_FLAGGED']) && $msg['FLAG_FLAGGED'] == true) {
                     $td_str .= _('<IMG SRC="../plugins/msg_flags/flagged.gif" border="0" height="10" width="10"> ');
                 }
-		if ($default_use_priority) {
+                if ($default_use_priority) {
                     if ( ($msg['PRIORITY'] == 1) || ($msg['PRIORITY'] == 2) ) {
                         $td_str .= '<IMG SRC="../plugins/msg_flags/prio_high.gif" border="0" height="10" width="5"> ';
                     }
                     else if ($msg['PRIORITY'] == 5) {
                         $td_str .= '<IMG SRC="../plugins/msg_flags/prio_low.gif" border="0" height="10" width="5"> ';
                     }
-		    else
-		    {
-			$td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" width="5"> ';
-		    }
+                    else
+                    {
+                        $td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" width="5"> ';
+                    }
                 }
-		if ($msg['TYPE0'] == 'multipart') {
+                if ($msg['TYPE0'] == 'multipart') {
                     $td_str .= '<IMG SRC="../plugins/msg_flags/attach.gif" border="0" height="10" width="6">';
                 }
-		else
-		{
-		    $td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" width="6">';
-		}
-		
-		$msg_icon = '';
-		if (!isset($msg['FLAG_SEEN']) || ($msg['FLAG_SEEN']) == false) 
-		{
-    		    $msg_alt = '(New)';
-		    $msg_title = '(New)';
-    		    $msg_icon .= '../plugins/msg_flags/msg_new';
-		} 
-		else 
-		{
-		    $msg_alt = '(Read)';
-		    $msg_title = '(Read)';
-    		    $msg_icon .= "../plugins/msg_flags/msg_read";
-    		}
-		if (isset($msg['FLAG_DELETED']) && ($msg['FLAG_DELETED']) == true)
-		{
-		    $msg_icon .= '_deleted';
-		}
-		if (isset($msg['FLAG_ANSWERED']) && ($msg['FLAG_ANSWERED']) == true)
-		{
-		    $msg_icon .= '_reply';
-		}
-    		$td_str .= '<IMG SRC="' . $msg_icon . '.gif" border="0" alt="'. $msg_alt . '" title="' . $msg_title . '" height="12" width="18" ></small></b>';
-		
+                else
+                {
+                    $td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" width="6">';
+                }
+
+                $msg_icon = '';
+                if (!isset($msg['FLAG_SEEN']) || ($msg['FLAG_SEEN']) == false)
+                {
+                    $msg_alt = '(New)';
+                    $msg_title = '(New)';
+                    $msg_icon .= '../plugins/msg_flags/msg_new';
+                }
+                else
+                {
+                    $msg_alt = '(Read)';
+                    $msg_title = '(Read)';
+                    $msg_icon .= "../plugins/msg_flags/msg_read";
+                }
+                if (isset($msg['FLAG_DELETED']) && ($msg['FLAG_DELETED']) == true)
+                {
+                    $msg_icon .= '_deleted';
+                }
+                if (isset($msg['FLAG_ANSWERED']) && ($msg['FLAG_ANSWERED']) == true)
+                {
+                    $msg_icon .= '_reply';
+                }
+                $td_str .= '<IMG SRC="' . $msg_icon . '.gif" border="0" alt="'. $msg_alt . '" title="' . $msg_title . '" height="12" width="18" >';
+                do_hook("msg_envelope");
+                $td_str .= '</small></b>';
+
                 echo html_tag( 'td',
                                $td_str,
                                'right',
                                $hlt_color,
                                'nowrap' );
                 break;
-                case 6: /* size */
+            case 6: /* size */
                 echo html_tag( 'td',
                                $bold . $fontstr . show_readable_size($msg['SIZE']) .
                                $fontstr_end . $bold_end,
@@ -306,7 +316,7 @@ function getServerMessages($imapConnection, $start_msg, $show_num, $num_msgs, $i
         } else {
             $end_loop = $show_num;
         }
-        return fillMessageArray($imapConnection,$id,$end_loop);
+        return fillMessageArray($imapConnection,$id,$end_loop,$show_num);
     } else {
         return false;
     }
@@ -331,6 +341,9 @@ function getSelfSortMessages($imapConnection, $start_msg, $show_num,
         if ($sort < 6 ) {
             $end = $num_msgs;
             $end_loop = $end;
+	    /* set shownum to 999999 to fool sqimap_get_small_header_list
+	       and rebuild the msgs_str to 1:* */
+	    $show_num = 999999;
         } else {
             /* if it's not sorted */
             if ($start_msg + ($show_num - 1) < $num_msgs) {
@@ -354,7 +367,7 @@ function getSelfSortMessages($imapConnection, $start_msg, $show_num,
                 $end_loop = $show_num;
             }
         }
-        $msgs = fillMessageArray($imapConnection,$id,$end_loop);
+        $msgs = fillMessageArray($imapConnection,$id,$end_loop, $show_num);
     }
     return $msgs;
 }
@@ -385,7 +398,7 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
         $msgs = array();
     }
 
-    $start = microtime();
+    //$start = microtime();
     /* If autoexpunge is turned on, then do it now. */
     $mbxresponse = sqimap_mailbox_select($imapConnection, $mailbox);
     $srt = $sort;
@@ -422,8 +435,13 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
             $mode = '';
         }
 
-        sqsession_unregister('msort');
-        sqsession_unregister('msgs');
+	if ($use_cache) {
+	    sqgetGlobalVar('msgs', $msgs, SQ_SESSION);
+	    sqgetGlobalVar('msort', $msort, SQ_SESSION);
+	} else {
+    	    sqsession_unregister('msort');
+    	    sqsession_unregister('msgs');
+	}
         switch ($mode) {
             case 'thread':
                 $id   = get_thread_sort($imapConnection);
@@ -465,6 +483,7 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
         } // switch
         sqsession_register($msort, 'msort');
         sqsession_register($msgs,  'msgs');
+
     } /* if exists > 0 */
 
     $res = getEndMessage($start_msg, $show_num, $num_msgs);
@@ -499,7 +518,7 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
 
     mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color); 
     echo '</td></tr></table>';
-    $t = elapsed($start);
+    //$t = elapsed($start);
     //echo("elapsed time = $t seconds\n");
 }
 
@@ -539,8 +558,8 @@ function calc_msort($msgs, $sort) {
     return $msort;
 }
 
-function fillMessageArray($imapConnection, $id, $count) {
-    return sqimap_get_small_header_list($imapConnection, $id);
+function fillMessageArray($imapConnection, $id, $count, $show_num=false) {
+    return sqimap_get_small_header_list($imapConnection, $id, $show_num);
 }
 
 
@@ -677,7 +696,9 @@ function mail_message_listing_beginning ($imapConnection,
      * This is the beginning of the message list table.
      * It wraps around all messages
      */
-    echo '<form name="messageList" method="post" action="move_messages.php">' ."\n"
+    $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
+    $form_name = "FormMsgs" . $safe_name;
+    echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n"
 	. $moveFields
         . html_tag( 'table' ,
             html_tag( 'tr',
@@ -885,18 +906,22 @@ function get_selectall_link($start_msg, $sort) {
 
     $result = '';
     if ($javascript_on) {
+        $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
+        $func_name = "CheckAll" . $safe_name;
+        $form_name = "FormMsgs" . $safe_name;
         $result = '<script language="JavaScript" type="text/javascript">'
                 . "\n<!-- \n"
-                . "function CheckAll() {\n"
-                . "  for (var i = 0; i < document.messageList.elements.length; i++) {\n"
-                . "    if(document.messageList.elements[i].type == 'checkbox'){\n"
-                . "      document.messageList.elements[i].checked = "
-                . "        !(document.messageList.elements[i].checked);\n"
+                . "function " . $func_name . "() {\n"
+                . "  for (var i = 0; i < document." . $form_name . ".elements.length; i++) {\n"
+                . "    if(document." . $form_name . ".elements[i].type == 'checkbox'){\n"
+                . "      document." . $form_name . ".elements[i].checked = "
+                . "        !(document." . $form_name . ".elements[i].checked);\n"
                 . "    }\n"
                 . "  }\n"
                 . "}\n"
                 . "//-->\n"
-                . '</script><a href="#" onClick="CheckAll();">' . _("Toggle All")
+                . '</script><a href="javascript:void(0)" onClick="' . $func_name . '();">' . _("Toggle All")
+/*                . '</script><a href="javascript:' . $func_name . '()">' . _("Toggle All")*/
                 . "</a>\n";
     } else {
         if (strpos($PHP_SELF, "?")) {
@@ -1270,4 +1295,4 @@ function handleAsSent($mailbox) {
     return $handleAsSent_result;
 }
 
-?>
\ No newline at end of file
+?>
