@@ -9,7 +9,7 @@
  * This is the code for the left bar. The left bar shows the folders
  * available, and has cookie information.
  *
- * $Id: left_main.php,v 1.154 2003/03/11 17:39:19 kink Exp $
+ * $Id: left_main.php,v 1.154.2.1 2003/06/24 23:20:12 pdontthink Exp $
  */
 
 /* Path for SquirrelMail required files. */
@@ -100,6 +100,10 @@ function formatMailboxName($imapConnection, $box_array) {
                     "&nbsp;&nbsp;(<A HREF=\"empty_trash.php\" style=\"text-decoration:none\">"._("purge")."</A>)" .
                     "</small>";
         }
+    } else {
+        $line .= concat_hook_function('left_main_after_each_folder',
+                                      array(isset($numMessages) ? $numMessages : '',
+                                            $real_box, $imapConnection));
     }
 
     /* Return the final product. */
@@ -164,7 +168,7 @@ function compute_folder_children(&$parbox, $boxcount) {
 function create_collapse_link($boxnum) {
     global $boxes, $imapConnection, $unseen_notify, $color;
     $mailbox = urlencode($boxes[$boxnum]['unformatted']);
-        
+
     /* Create the link for this collapse link. */
     $link = '<a target="left" style="text-decoration:none" ' .
             'href="left_main.php?';
